@@ -7,6 +7,8 @@ from pollination.honeybee_radiance.sky import CreateSkyDome, CreateSkyMatrix
 from pollination.honeybee_radiance.grid import SplitGridFolder, MergeFolderData
 from pollination.honeybee_radiance.post_process import AnnualDaylightMetrics
 
+from pollination.honeybee_vtk.config import Config as VTKConfig
+from pollination.honeybee_vtk.translate import Translate as TranslateVTKJS
 
 # input/output alias
 from pollination.alias.inputs.model import hbjson_model_grid_input
@@ -14,7 +16,8 @@ from pollination.alias.inputs.wea import wea_input_timestep_check
 from pollination.alias.inputs.north import north_input
 from pollination.alias.inputs.radiancepar import rad_par_annual_input, \
     daylight_thresholds_input
-from pollination.alias.inputs.grid import grid_filter_input
+from pollination.alias.inputs.grid import grid_filter_input, \
+    min_sensor_count_input, cpu_count
 from pollination.alias.inputs.schedule import schedule_csv_input
 from pollination.alias.outputs.daylight import annual_daylight_results, \
     daylight_autonomy_results, continuous_daylight_autonomy_results, \
@@ -38,15 +41,21 @@ class AnnualDaylightEntryPoint(DAG):
 
     cpu_count = Inputs.int(
         default=50,
-        description='The maximum number of CPUs for parallel execution.',
-        spec={'type': 'integer', 'minimum': 1}
+        description='The maximum number of CPUs for parallel execution. This will be '
+        'used to determine the number of sensors run by each worker.',
+        spec={'type': 'integer', 'minimum': 1},
+        alias=cpu_count
     )
 
-    sensor_count = Inputs.int(
-        description='Minimum number of sensors in each sensor grid after redistributing '
-        'the sensors based on cpu_count. Use this value to ensure the parallelization '
-        'does not result in generating very small sensor grids. The default value is '
-        'set to 1.', default=1, spec={'type': 'integer', 'minimum': 1}
+    min_sensor_count = Inputs.int(
+        description='The minimum number of sensors in each sensor grid after '
+        'redistributing the sensors based on cpu_count. This value takes '
+        'precedence over the cpu_count and can be used to ensure that '
+        'the parallelization does not result in generating unnecessarily small '
+        'sensor grids. The default value is set to 1, which means that the '
+        'cpu_count is always respected.', default=1,
+        spec={'type': 'integer', 'minimum': 1},
+        alias=min_sensor_count_input
     )
 
     radiance_parameters = Inputs.str(
@@ -142,8 +151,8 @@ class AnnualDaylightEntryPoint(DAG):
     )
     def split_grid_folder(
         self, input_folder=create_rad_folder._outputs.model_folder,
-        grid_count=cpu_count, sensor_count=sensor_count
-        ):
+        cpu_count=cpu_count, cpus_per_grid=3, min_sensor_count=min_sensor_count
+    ):
         """Split sensor grid folder based on the number of CPUs."""
         return [
             {
@@ -191,7 +200,7 @@ class AnnualDaylightEntryPoint(DAG):
     @task(template=CreateSkyMatrix)
     def create_direct_sky(
         self, north=north, wea=wea, sky_type='sun-only', sun_up_hours='sun-up-hours'
-            ):
+    ):
         return [
             {
                 'from': CreateSkyMatrix()._outputs.sky_matrix,
@@ -261,6 +270,38 @@ class AnnualDaylightEntryPoint(DAG):
             }
         ]
 
+    @task(
+        template=VTKConfig, needs=[calculate_annual_metrics],
+        sub_paths={'input_file': 'metrics_info.json'}
+    )
+    def convert_metrics_info(
+            self, input_file=calculate_annual_metrics._outputs.annual_metrics
+    ):
+        return [
+            {
+                'from': VTKConfig()._outputs.config,
+                'to': 'metrics/config.json'
+            }
+        ]
+
+    @task(template=TranslateVTKJS, needs=[convert_metrics_info])
+    def create_vtkjs(
+            self, hbjson_file=model, file_type='vtkjs', grid_options='points',
+            config_path=convert_metrics_info._outputs.config,
+            data='metrics'
+        ):
+        return [
+            {
+                'from': TranslateVTKJS()._outputs.output_file,
+                'to': 'visualization/annual_daylight.vtkjs'
+            }
+        ]
+
+    visualization = Outputs.file(
+        source='visualization/annual_daylight.vtkjs',
+        description='Results visualization in 3D in vtkjs format.'
+    )
+
     results = Outputs.folder(
         source='results', description='Folder with raw result files (.ill) that '
         'contain illuminance matrices.', alias=annual_daylight_results
